mathtools.NegativeInfinity
==========================

.. abjad-lineage:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.NegativeInfinity

.. autoclass:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.NegativeInfinity
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.NegativeInfinity.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.NegativeInfinity.__eq__
   :noindex:

.. automethod:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.NegativeInfinity.__ge__
   :noindex:

.. automethod:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.NegativeInfinity.__gt__
   :noindex:

.. automethod:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.NegativeInfinity.__le__
   :noindex:

.. automethod:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.NegativeInfinity.__lt__
   :noindex:

.. automethod:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.NegativeInfinity.__ne__
   :noindex:

.. automethod:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.NegativeInfinity.__repr__
   :noindex:
